FillCode

Enum FillCode 

pub enum FillCode {
    Fil,
    Fill,
    Filll,
}
Positively silly enum, but it solves all kinds of issues with the Glue struct most importantly allows us to keep deriving the Copy trait, and avoids storing strings in Glue objects

Variants



Fil



Fill



Filll

Implementations

Source

impl FillCode

pub fn new(index: usize) -> Option<FillCode>

pub fn from(ftype: &str) -> Option<FillCode>

pub fn to_str(&self) -> &'static str