pub enum FillCode {
Fil,
Fill,
Filll,
}Expand description
Positively silly enum, but it solves all kinds of issues with the Glue struct most importantly allows us to keep deriving the Copy trait, and avoids storing strings in Glue objects
Variants
Implementations